==> sededu-1.0.3a-py3-none-any.whl: sededu/modules/stratigraphy/stratigraphic_filter/README.md <==
# The Stratigraphic Filter

This explores the erosional stratigraphic filter on stratigraphy with a simple one-dimensional model of surface elevation over time.

This repository is also linked into the [SedEdu suite of education modules](https://github.com/amoodie/sededu), and can be accessed there as well.

![demo image](./private/demo.png "demo of the module")<!-- .element height="50%" width="50%" -->



## Installation and running the module

Visit the section of the text below for more information on installing and executing the `stratigraphic_filter_toy` program on your computer. 


### Requirements
This module depends on Python3, and the libraries `numpy` and `matplotlib`. 

#### Anaconda installation
It is recommended that you install Anaconda, which is an open source distribution of Python. It comes with many basic scientific libraries, some of which are used in the module. Anaconda can be downloaded at https://www.anaconda.com/download/ for Windows, macOS, and Linux. Please follow the instruction provided in the website as to how to install and setup Python on your computer.

#### Custom Python installation
If you want a more flexible and lightweight Python distribution, you can use whatever your favorite package manager is distributing (e.g., `homebrew` or `apt`), check the [Windows downloads here](https://www.python.org/downloads/windows/), or compile [from source](https://www.python.org/downloads/source/).

Whatever method you choose, you will need to install the dependencies. installation by `pip` is easiest, and probably supported if you used anything but compiling from source.


### Download the source code

#### grab the zip
You can download this entire repository as a `.zip` by clicking the "Clone or download button on this page", or by [clicking here](https://github.com/amoodie/flooding_in_deltas/archive/master.zip) to get a `.zip` folder. Unzip the folder in your preferred location.

#### git 
If you have installed `git` and are comfortable working with it, you can simply clone the repository to your preferred location.

```
https://github.com/amoodie/stratigraphic_filter_toy.git
```


### Run the module
Run the module by command line, with
```
python3 <path-to-the-repo-folder>/src/stratigraphic_filter_toy.py
```



## Module worksheet information

Worksheets are being written to accompany the GUI module. The aim of the worksheets is to help guide a discussion about flooding on deltas or rivers, as may be discussed in Earth Science courses. The modules currently available are targeted at specific age groups:

* none

**Educators:** please let me know if you used this module, and if there are any ways you can see for us to help facilitate this sort of module in the future. Your feedback is very much appreciated. Email to Andrew Moodie, amoodie@rice.edu.



## Disclaimer

The module was created by Andrew J. Moodie as part of the SedEdu project.
AJM was supported by an NSF Graduate Research Fellowship under Grant No. 1450681.
Any opinion, findings, and conclusions or recommendations expressed in this material are those of the author(s) and do not necessarily reflect the views of the National Science Foundation.

==> sededu-1.0.12-py3-none-any.whl: sededu/modules/stratigraphy/stratigraphic_filter/README.md <==
# The Stratigraphic Filter

This explores the erosional stratigraphic filter on stratigraphy with a simple one-dimensional model of surface elevation over time.

This repository is also linked into the [SedEdu suite of education modules](https://github.com/amoodie/sededu), and can be accessed there as well.

![demo image](./private/demo.png "demo of the module")<!-- .element height="50%" width="50%" -->



## Installation and running the module

Visit the section of the text below for more information on installing and executing the `stratigraphic_filter_toy` program on your computer. 


### Requirements
This module depends on Python3, and the libraries `numpy` and `matplotlib`. 

#### Anaconda installation
It is recommended that you install Anaconda, which is an open source distribution of Python. It comes with many basic scientific libraries, some of which are used in the module. Anaconda can be downloaded at https://www.anaconda.com/download/ for Windows, macOS, and Linux. Please follow the instruction provided in the website as to how to install and setup Python on your computer.

#### Custom Python installation
If you want a more flexible and lightweight Python distribution, you can use whatever your favorite package manager is distributing (e.g., `homebrew` or `apt`), check the [Windows downloads here](https://www.python.org/downloads/windows/), or compile [from source](https://www.python.org/downloads/source/).

Whatever method you choose, you will need to install the dependencies. installation by `pip` is easiest, and probably supported if you used anything but compiling from source.


### Download the source code

#### grab the zip
You can download this entire repository as a `.zip` by clicking the "Clone or download button on this page", or by [clicking here](https://github.com/amoodie/stratigraphic_filter_toy/archive/master.zip) to get a `.zip` folder. Unzip the folder in your preferred location.

#### git 
If you have installed `git` and are comfortable working with it, you can simply clone the repository to your preferred location.

```
https://github.com/amoodie/stratigraphic_filter_toy.git
```


### Run the module
Run the module by command line, with
```
python3 <path-to-the-repo-folder>/src/stratigraphic_filter_toy.py
```



## Module worksheet information

Worksheets are being written to accompany the GUI module. The aim of the worksheets is to help guide a discussion about flooding on deltas or rivers, as may be discussed in Earth Science courses. The modules currently available are targeted at specific age groups:

* none

**Educators:** please let me know if you used this module, and if there are any ways you can see for us to help facilitate this sort of module in the future. Your feedback is very much appreciated. Email to Andrew Moodie, amoodie@rice.edu.



## Disclaimer

The module was created by Andrew J. Moodie as part of the SedEdu project.
AJM was supported by an NSF Graduate Research Fellowship under Grant No. 1450681.
Any opinion, findings, and conclusions or recommendations expressed in this material are those of the author(s) and do not necessarily reflect the views of the National Science Foundation.
